@@ -428,6 +428,7 @@ class HalohaloAPI:
     def segment_bulk_writer(
         self,
         input_df,
+        flags,
         target_segment,
         target_collection,
         mongo_aws_access_key_id,
@@ -458,15 +459,22 @@ class HalohaloAPI:
         except Exception as e:
             raise Exception("ERROR:", e)
 
-        flags = []
-        # --no existing records in db for target segment, add all as new records
+        # --no existing records in db for target segment, return error
         if existing_df.count() == 0:
             if int(existing_df.count()) == 0:
                 raise Exception(
                     f"Target segment {target_segment} does not exist in {target_collection}"
                 )
         else:
-            flags = ["activate", "new", "deactivate"]
+            if len(flags) == 0:
+                flags = ["activate", "new", "deactivate"]
+            else:
+                # check if there is
+                for user_flag in flags:
+                    if user_flag not in ["activate", "new", "deactivate"]:
+                        raise Exception(
+                            f'Wrong flag value: {user_flag}. Flag values can be ["activate","new","deactivate"]'
+                        )
 
         def ingest_parallelize_spark_df_multithread(
             rows,
@@ -538,6 +546,7 @@ class HalohaloAPI:
                 existing_df.user_id == source_df.source_user_id,
                 existing_df.segment_name == source_df.source_segment_name,
             ]
+
             if flag == "new":
 
                 # ---- new
