@@ -22,7 +22,12 @@ class ModelAPI:
         headers : Object
             Headers to be passed into requests
         """
-        self.headers = {"Content-Type": "application/json", "Connection": "close"}
+        self.headers = {
+            "Content-Type": "application/json",
+            "Accept": "*/*",
+            "Accept-Encoding": "gzip, deflate, br",
+            "Connection": "close",
+        }
         if env == "dev":
             # TODO: hostnames are only temporary
             self.base_url = "http://a964e32654136468fb87dfa602143604-d83587f2b0590882.elb.ap-southeast-1.amazonaws.com"
@@ -49,6 +54,13 @@ class ModelAPI:
             res = requests.post(
                 url=endpoint_url, data=json.dumps(request_body), headers=self.headers
             )
+            # Retry request
+            if res.status_code == 500 or res.status_code == 502:
+                res = requests.post(
+                    url=endpoint_url,
+                    data=json.dumps(request_body),
+                    headers=self.headers,
+                )
             res.raise_for_status()
             return res.json()
         except HTTPError as errh:
@@ -81,6 +93,13 @@ class ModelAPI:
             res = requests.post(
                 url=endpoint_url, data=json.dumps(request_body), headers=self.headers
             )
+            # Retry request
+            if res.status_code == 500 or res.status_code == 502:
+                res = requests.post(
+                    url=endpoint_url,
+                    data=json.dumps(request_body),
+                    headers=self.headers,
+                )
             res.raise_for_status()
             return res.json()
         except HTTPError as errh:
