@@ -289,6 +289,9 @@ class SagemakerFeatureStore:
             if "redis" in online_store_sources:
                 tags.append({"online-store": "redis"})
                 new_tags.append({"Key": "online-store", "Value": "redis"})
+            # remove duplicate tags
+            tags = [dict(t) for t in {tuple(d.items()) for d in tags}]
+            new_tags = [dict(t) for t in {tuple(d.items()) for d in new_tags}]
 
         # Feature group creation
         feature_group.create(
@@ -626,24 +629,12 @@ class SagemakerFeatureStore:
                     config=Config(retries={"max_attempts": 10, "mode": "standard"}),
                 )
 
+                # Ingest to Redis first, if applicable
                 if is_redis:
                     ops = 0
                     pipe = redis_client.pipeline()
-                for row in rows:
-                    # Ingest to AWS Sagemaker FS
-                    if ingest_to_aws:
-                        record = [
-                            {"FeatureName": column, "ValueAsString": str(row[column])}
-                            for column in row.__fields__
-                        ]
-                        resp = runtime.put_record(
-                            FeatureGroupName=feature_group_name, Record=record
-                        )
-                        if not resp["ResponseMetadata"]["HTTPStatusCode"] == 200:
-                            raise (f"PutRecord failed: {resp}")
-
-                    # Ingest to Redis online store
-                    if is_redis:
+                    for row in rows:
+                        # Ingest to Redis online store
                         key_name = "{{{}}}:{}".format(
                             feature_group_name, str(row[record_identifier])
                         )
@@ -662,10 +653,24 @@ class SagemakerFeatureStore:
                             pipe.execute()
                             pipe = redis_client.pipeline()
                             ops = 0
-                if is_redis and ops > 0:
-                    time.sleep(1 * (0.8 + random.random() * 0.4))
-                    pipe.execute()
-                print("Done writing to Redis")
+                    if ops > 0:
+                        time.sleep(1 * (0.8 + random.random() * 0.4))
+                        pipe.execute()
+                        print("Done writing to Redis")
+
+                # Ingest to AWS Sagemaker FS
+                if ingest_to_aws:
+                    for row in rows:
+                        record = [
+                            {"FeatureName": column, "ValueAsString": str(row[column])}
+                            for column in row.__fields__
+                        ]
+                        resp = runtime.put_record(
+                            FeatureGroupName=feature_group_name, Record=record
+                        )
+                        if not resp["ResponseMetadata"]["HTTPStatusCode"] == 200:
+                            raise (f"PutRecord failed: {resp}")
+                    print("Done writing to Sagemaker")
 
             # Main
             rows = list(rows)
